==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/vi/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Đọc thêm",

    "audit_help" => "Chọn hộp này sẽ chỉnh sửa bản ghi nội dung để phản ánh vị trí mới này. Bỏ chọn nó sẽ chỉ ghi lại vị trí trong nhật ký kiểm tra. <br> <br> Lưu ý rằng nội dung này đã được kiểm tra, nó sẽ không thay đổi vị trí của người, tài sản hoặc vị trí mà nó được kiểm tra.",

    'assets' => 'Nội dung là các mục được theo dõi bằng số sê-ri hoặc thẻ nội dung. Chúng có xu hướng trở thành những mặt hàng có giá trị cao hơn khi việc xác định một mặt hàng cụ thể rất quan trọng.',

    'categories' => 'Danh mục giúp bạn sắp xếp các mặt hàng của mình. Một số danh mục mẫu có thể là &quot; Máy tính để bàn &quot;, &quot; Máy tính xách tay &quot;, &quot; Điện thoại Di động &quot;, &quot; Máy tính bảng&quot;, v.v., nhưng bạn có thể sử dụng các danh mục theo bất kỳ cách nào phù hợp với mình.',

    'accessories' => 'Phụ kiện là bất cứ thứ gì bạn cấp cho người dùng nhưng không có số sê-ri (hoặc bạn không quan tâm đến việc theo dõi chúng duy nhất). Ví dụ, chuột máy tính hoặc bàn phím.',

    'companies'     => 'Danh mục các công ty có thể được sử dụng như là một trường định danh đơn giản hoặc có thể được sử dụng để lọc ra số lượng hạn chế các tài sản, người dùng, v. v nếu như hỗ chợ công ty được kích hoạt trong thiết lập quản trị (Admin settings) của bạn.',

    'components'    => 'Thành phần là các mục là một phần của tài sản, ví dụ như ổ cứng HDD, RAM, v. v.',

    'consumables'   => 'Vật phẩm tiêu hao là bất cứ thứ gì đã mua sẽ được sử dụng hết theo thời gian. Ví dụ: mực máy in hoặc giấy máy photocopy.',

    'depreciations' => 'Bạn có thể thiết lập khấu hao tài sản để khấu hao tài sản dựa trên khấu hao đường thẳng.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/vi/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Đọc thêm',

    'audit_help' => 'Chọn hộp này sẽ chỉnh sửa bản ghi nội dung để phản ánh vị trí mới này. Bỏ chọn nó sẽ chỉ ghi lại vị trí trong nhật ký kiểm tra. <br> <br> Lưu ý rằng nội dung này đã được kiểm tra, nó sẽ không thay đổi vị trí của người, tài sản hoặc vị trí mà nó được kiểm tra.',

    'assets' => 'Nội dung là các mục được theo dõi bằng số sê-ri hoặc thẻ nội dung. Chúng có xu hướng trở thành những mặt hàng có giá trị cao hơn khi việc xác định một mặt hàng cụ thể rất quan trọng.',

    'categories' => 'Danh mục giúp bạn sắp xếp các mặt hàng của mình. Một số danh mục mẫu có thể là &quot; Máy tính để bàn &quot;, &quot; Máy tính xách tay &quot;, &quot; Điện thoại Di động &quot;, &quot; Máy tính bảng&quot;, v.v., nhưng bạn có thể sử dụng các danh mục theo bất kỳ cách nào phù hợp với mình.',

    'accessories' => 'Phụ kiện là bất cứ thứ gì bạn cấp cho người dùng nhưng không có số sê-ri (hoặc bạn không quan tâm đến việc theo dõi chúng duy nhất). Ví dụ, chuột máy tính hoặc bàn phím.',

    'companies'     => 'Danh mục các công ty có thể được sử dụng như là một trường định danh đơn giản hoặc có thể được sử dụng để lọc ra số lượng hạn chế các tài sản, người dùng, v. v nếu như hỗ chợ công ty được kích hoạt trong thiết lập quản trị (Admin settings) của bạn.',

    'components'    => 'Thành phần là các mục là một phần của tài sản, ví dụ như ổ cứng HDD, RAM, v. v.',

    'consumables'   => 'Vật phẩm tiêu hao là bất cứ thứ gì đã mua sẽ được sử dụng hết theo thời gian. Ví dụ: mực máy in hoặc giấy máy photocopy.',

    'depreciations' => 'Bạn có thể thiết lập khấu hao tài sản để khấu hao tài sản dựa trên khấu hao đường thẳng.',

];
